@@ -93,6 +93,9 @@ class App(object):
     def get_icon_url(self):
         return ''
 
+    def get_page_title(self):
+        return 'Tropofy'
+
     def get_gui(self):
         raise NotImplementedError
 
@@ -189,7 +192,8 @@ class App(object):
 
     def export_data_set(self, data_set):
         response = Response(self.get_data_set_as_excel_wb_string_repr(data_set))
-        response.headers['Content-Disposition'] = ("attachment; filename=export.xlsx")
+        file_name = "{name}.xlsx".format(name=data_set.name if data_set else 'export')
+        response.headers['Content-Disposition'] = ("attachment; filename={file_name}".format(file_name=file_name))
         return response
 
     def get_path_of_file_in_app_folder(self, file_name):  # TODO: Should add docs to this. Is useful to be exposed.
@@ -368,7 +372,7 @@ class AppWithDataSets(App):
     def get_parameters(self):
         """Define parameters to be used in the app.
 
-        :returns: list of :class:`tropofy.app.Parameter` objects
+        :returns: list of :class:`tropofy.app.Parameter` mixins
         :rtype: list
 
         Example from :ref:`Plotting in 3D Example App<example_scipy_numpy_matplotlib_plotting_in_3d>`:
@@ -391,6 +395,13 @@ class AppWithDataSets(App):
         """
         return False
 
+    def get_page_title(self):
+        """(Optional) Set the title for the webpage. In most browsers, used as text in the tab title. Default is 'Tropofy'.
+
+        :type: str
+        """
+        return 'Tropofy'
+
 
 def make_safe_url_name(name):
     return name.lower().replace(' ', '_').replace(',', '')  # Not entirely safe if people do crazy names!
@@ -444,7 +455,8 @@ class StepGroup(object):
     def __init__(self, name="Step Group", steps=None):
         self.id = StepGroup.step_group_indexer
         StepGroup.step_group_indexer += 1
-        self.name = name
+        # dodgy hack to prevent apostrophes in help text corrupting generated javascript
+        self.name = name.replace('\'', '')
         self.steps = steps if steps else []
 
     def add_step(self, step):
@@ -507,7 +519,8 @@ class Step(object):
     def __init__(self, name="Step", widgets=None, help_text=None, hide_navigation=False):
         self.id = Step.global_step_indexer
         Step.global_step_indexer += 1
-        self.name = name
+        # dodgy hack to prevent apostrophes in help text corrupting generated javascript
+        self.name = name.replace('\'', '')
         self.help_text = help_text
         self.hide_navigation = hide_navigation
         self.widgets = []  # they get filled out in the func below
