@@ -344,7 +344,11 @@ class Validator():
                 try:
                     value = datetime.strptime(value, '%d/%m/%Y').date()
                 except:
-                    pass
+                    try:
+                        value = datetime.strptime(value, '%Y-%m-%d').date()
+                    except:
+                        pass
+
         if isinstance(value, datetime):
             value = value.date()
         if not isinstance(value, date):
