@@ -38,14 +38,14 @@ class ClassWsMapping(ClassTabularDataMapping):
     :type ws_name: str
     :param attribute_column_aliases: dict of class attribute to col alias.
     :type attribute_column_aliases: dict
-    :param process_objects: (Optional) Function that processes the objects of class\_ loaded from Excel. Must accept a single parameter which will be passed a list of objects of class\_.
-       If no function is passed, default behaviour is to assume class\_ is a SQLA class, and attempt to write the objects to the database.
+    :param process_objects: (Optional) Function that processes the mixins of class\_ loaded from Excel. Must accept a single parameter which will be passed a list of mixins of class\_.
+       If no function is passed, default behaviour is to assume class\_ is a SQLA class, and attempt to write the mixins to the database.
     :type process_objects: function
     :param get_objects: (Optional - default :func:`tropofy.file_io.ClassTabularDataMapping.get_all_sqla_objects_of_class_in_data_set`)
-     A function that accepts ``data_set`` and ``class_`` as parameters and returns a list of objects of ``class_``.
+     A function that accepts ``data_set`` and ``class_`` as parameters and returns a list of mixins of ``class_``.
     :type get_objects: function
-    :param objects: (Optional - default None) Specify objects instead of dynamically generating them with ``get_objects``.
-     A list of objects of ``class_`` to be included in export. Will overide ``get_objects`` if value is not None.
+    :param objects: (Optional - default None) Specify mixins instead of dynamically generating them with ``get_objects``.
+     A list of mixins of ``class_`` to be included in export. Will overide ``get_objects`` if value is not None.
     :type objects: list
 
     .. note:: To specify the order in which columns are written, use a ``collections.OrderedDict`` (Python built-in) for ``attribute_column_aliases``.
@@ -145,8 +145,8 @@ class ExcelWriter(object):
 
         If ``ordered_class_ws_mappings`` is not passed, a 'full export' of all data in the data set will be made, with one worksheet made for each SQLA ORM class.
 
-        If no ``objects`` or ``get_objects`` param is passed to a ``ordered_class_ws_mapping``, it is assumed that ``ordered_class_ws_mapping.class_`` is a SQLA ORM
-        class, and all objects in the database for this ``data_set`` will be written to Excel.
+        If no ``mixins`` or ``get_objects`` param is passed to a ``ordered_class_ws_mapping``, it is assumed that ``ordered_class_ws_mapping.class_`` is a SQLA ORM
+        class, and all mixins in the database for this ``data_set`` will be written to Excel.
 
         :param data_set: The DataSet object on which queries can be made to access the apps data.
         :type data_set: :class:`tropofy.app.AppDataSet`
@@ -157,6 +157,8 @@ class ExcelWriter(object):
         if ordered_class_ws_mappings is None:
             ordered_class_ws_mappings = ClassWsMapping.create_ordered_mappings_from_sqla_classes()
         for m in ordered_class_ws_mappings:
+            if data_set is None:  # This would happen when creating Excel template - no objects to write
+                m.objects = []
             m.objects = m.objects if m.objects is not None else m.get_objects(data_set, m.class_)
         wb = cls._create_excel_wb_from_class_mappings(ordered_class_ws_mappings)
         return save_virtual_workbook(wb)
@@ -221,7 +223,7 @@ class ExcelWriter(object):
                         try:
                             value = getattr(obj, mapping.get_attribute_from_column_name(col_name))
                         except AttributeError:
-                            print('Object in ClassWsMappingForExport.objects does not match ClassWsMappingForExport object and col definition')
+                            print('Object in ClassWsMappingForExport.mixins does not match ClassWsMappingForExport object and col definition')
                             raise
 
                         if isinstance(value, datetime.timedelta):
@@ -244,9 +246,9 @@ class ExcelReader(object):
     """Utility class for reading data from Microsoft Excel files. Supports .xlsx, .xls, .xlsm formats.
 
     Each :class:`tropofy.file_io.read_write_xl.ClassWsMapping` maps a worksheet in the Excel file to a Python class.
-    These method will attempt to create objects of each :class:`tropofy.file_io.read_write_xl.ClassWsMapping` class from the
+    These method will attempt to create mixins of each :class:`tropofy.file_io.read_write_xl.ClassWsMapping` class from the
     corresponding mapping worksheet, and then pass them to the process_objects function of the mapping. In process_objects,
-    the objects can be transformed in any way, or left alone, and then finally some data would be written to the database to make it persist.
+    the mixins can be transformed in any way, or left alone, and then finally some data would be written to the database to make it persist.
 
     Any :class:`tropofy.file_io.read_write_xl.ClassWsMapping` that does not map to a worksheets in the Excel file will be ignored. A message will report
     that no instances of the class were loaded.
@@ -366,7 +368,7 @@ class ExcelReader(object):
                                 new_object.data_set_id = data_set.id
                             except AttributeError:
                                 # object doesn't have a data_set_id parameter.
-                                # Useful for using namedtuples as import objects that are then processed into objects on the data set in `mapping.process_objects`
+                                # Useful for using namedtuples as import mixins that are then processed into mixins on the data set in `mapping.process_objects`
                                 pass
                             new_objects.append(new_object)
 
