@@ -62,6 +62,7 @@ def run_app(request):
         'get_step_groups': [step_group.serialise() for step_group in app.get_ordered_step_groups()],
         'get_app_icon_url': app.get_icon_url(),
         'disable_forced_linear_workflow': app.disable_forced_linear_workflow(),
+        'page_title': app.get_page_title(),
     }
     result = proxy_request({'emulator_dict': emulator_dict})
     return Response(result.content)
@@ -178,7 +179,8 @@ def logout(request):
 
     mako_render_dict = request.app.get_home_page_configuration()
     mako_render_dict.update({
-        'login_screen_default_is_create_account': request.app.is_login_screen_default_create_account()
+        'login_screen_default_is_create_account': request.app.is_login_screen_default_create_account(),
+        'page_title': request.app.get_page_title(),
     })
     data = {'mako_render_dict': mako_render_dict}
     url = request.registry.settings.get('custom.gui_server_url') + '/' + request.app.url_name + '/homepage'
