@@ -35,10 +35,13 @@ class Chart(Widget):
     The following is a reference of the functions required to define a chart.
 
     """
-    (AREACHART, BARCHART, BUBBLECHART, CANDLESTICKCHART, COLUMNCHART, COMBOCHART, HISTOGRAM, GAUGE, GEOCHART, LINECHART, PIECHART, SCATTERCHART, STEPPEDAREACHART, TABLE, TIMELINE, TREEMAP) = (
-        'AreaChart', 'BarChart', 'BubbleChart', 'CandleStickChart', 'ColumnChart', 'ComboChart', 'Histogram', 'Gauge', 'GeoChart', 'LineChart', 'PieChart', 'ScatterChart', 'SteppedAreaChart', 'Table', 'Timeline', 'TreeMap',
+    (AREACHART, BARCHART, BUBBLECHART, CANDLESTICKCHART, COLUMNCHART, COMBOCHART, HISTOGRAM, GAUGE, GEOCHART, LINECHART, ORGCHART, PIECHART, SCATTERCHART, STEPPEDAREACHART, TABLE, TIMELINE, TREEMAP) = (
+        'AreaChart', 'BarChart', 'BubbleChart', 'CandleStickChart', 'ColumnChart', 'ComboChart', 'Histogram', 'Gauge', 'GeoChart', 'LineChart', 'OrgChart', 'PieChart', 'ScatterChart', 'SteppedAreaChart', 'Table', 'Timeline', 'TreeMap',
     )
 
+    def __init__(self, widget_subscriptions=None):
+        super(Chart, self).__init__(widget_subscriptions)
+
     def get_type(self):
         return "ChartWidget"
 
@@ -83,6 +86,7 @@ class Chart(Widget):
         * `GAUGE <https://developers.google.com/chart/interactive/docs/gallery/gauge>`_
         * `GEOCHART <https://developers.google.com/chart/interactive/docs/gallery/geochart>`_
         * `LINECHART <https://developers.google.com/chart/interactive/docs/gallery/linechart>`_
+        * `ORGCHART <https://developers.google.com/chart/interactive/docs/gallery/orgchart>`_
         * `PIECHART <https://developers.google.com/chart/interactive/docs/gallery/piechart>`_
         * `SCATTERCHART <https://developers.google.com/chart/interactive/docs/gallery/scatterchart>`_
         * `STEPPEDAREACHART <https://developers.google.com/chart/interactive/docs/gallery/steppedareachart>`_
