@@ -84,7 +84,8 @@ class NewDataSetForm(Form):
         app = threadlocal.get_current_request().app
 
         options = [name for name in app.get_example_app_names()]
-        options.append('None')
+        if app.new_app_config_dict.get("has_none_template"):
+            options.append('None')
 
         default = app.get_default_example_data_set_name()
 
@@ -93,7 +94,7 @@ class NewDataSetForm(Form):
                 name='data_set_template',
                 input_type='select',
                 default=default if default and default in options else options[0],
-                label='Template',
+                label=app.new_app_config_dict.get("data_set_template_label"),
                 options=options,
             ),
             Form.Element(
@@ -126,8 +127,12 @@ class ImportNewDataSetFileUpload(FileUpload):  # Warning: get_allowed_file_types
         ]
 
     def process_file(self, data_set, file_in_memory, result):
-        request = threadlocal.get_current_request()
-        data_set = request.app.create_new_data_set_for_user(authenticated_userid(request), None, "Imported '%s'" % (file_in_memory.filename))
+        request = threadlocal.get_current_request()  # TODO: Remove this - makes testing impossible! Add request to data_set on way through perhaps...
+        data_set = request.app.create_new_data_set_for_user(
+            user_email=authenticated_userid(request),
+            example_data_set_name=None,
+            specific_name="Imported '%s'" % (file_in_memory.filename),
+        )
         result['dataSetId'] = data_set.id
         result['dataSetName'] = data_set.name
         result['message'] = read_write_xl.ExcelReader.load_data_from_excel_file_in_memory(data_set, file_in_memory)
@@ -162,7 +167,10 @@ class ImportDataSetNameEdit(Form):
         except (NoResultFound, MultipleResultsFound):
             pass
 
-    def autosubmit_entire_form(self, data_set):
+    def is_autosubmit(self, data_set):
+        return True
+
+    def is_submit_entire_form(self, data_set):
         return True
 
     def is_hidden(self):
@@ -221,13 +229,12 @@ class ManageDataSetForm(Form):
                 data_set_select_form_element,
                 Form.Element(
                     name='new_data_set_name',
-                    input_type='text',
+                    input_type=Form.Element.TEXT,
                     label='New data set name',
-                    default='',
                 ),
                 Form.Element(
                     name='delete_data_set',
-                    input_type='text',
+                    input_type=Form.Element.TEXT,
                     label='',
                     default=False,
                     hidden=True
@@ -287,7 +294,6 @@ def get_existing_data_sets_form_select(data_set):
             return Form.Element(
                 name='data_set',
                 input_type='select',
-                default=options[0]['value'],
                 label='Data Set Name',
                 options=options,
                 disabled=len(options) == 0
