@@ -24,6 +24,8 @@ class SimpleGrid(GridWidget):
     :param source_class: A user defined SQLAlchemy Python class
     :param editable: (Optional - default True). Enables grid to be edited.
     :type editable: bool
+    :param widget_subscriptions: (Optional) Widget to subscribe to a triggered event of
+    :type widget_subscriptions: list of tuples of (tropofy.widget, str of trigger_event_name, str of subscribed_action)
 
     .. note::
         The source_class provided to a SimpleGrid must have the following properties:
@@ -35,10 +37,15 @@ class SimpleGrid(GridWidget):
     .. literalinclude:: ../../../tropofy/widgets/examples/widget_examples.py
         :pyobject: ConformingClass
     """
-    def __init__(self, source_class, editable=True, title=None):
+    def __init__(self, source_class, editable=True, title=None, embedded_form_class=None, desc_sort_cols=None, widget_subscriptions=None):
         self.source_class = source_class
         self.editable = editable
-        super(SimpleGrid, self).__init__(title=title)
+        super(SimpleGrid, self).__init__(
+            title=title,
+            embedded_form_class=embedded_form_class,
+            desc_sort_cols=desc_sort_cols,
+            widget_subscriptions=widget_subscriptions
+        )
 
     def get_type(self):
         return 'SimpleGrid'
@@ -99,7 +106,7 @@ class SimpleGrid(GridWidget):
 
     def get_qry_of_non_filtered_refresh_objects(self, data_set):
         """
-        :returns: SQLA qry object, that if executed, would return all objects in the grid - unfiltered and unsorted.
+        :returns: SQLA qry object, that if executed, would return all mixins in the grid - unfiltered and unsorted.
         
         Assumes data_set exists.
         """
