@@ -19,13 +19,29 @@ class WidgetConfigException(Exception):
 
 
 class Widget(object):
-    """A widget is a HTML interface to the database via a developer defined query or framework specified query"""
+    """A widget is a HTML interface to the database via a developer defined query or framework specified query
+
+    :param widget_subscriptions: (Optional) Widget to subscribe to a triggered event of
+    :type widget_subscriptions: list of tuples of (tropofy.widget, str of trigger_event_name, str of subscribed_action)
+    """
     widget_indexer = 0
     widget_dict = {}
 
     Action = namedtuple('Action', 'widget name')
     # all_actions = ['refresh', 'hide', 'show']
 
+    def __init__(self, widget_subscriptions=None):
+        if widget_subscriptions:
+            for widget_subscription in widget_subscriptions:
+                widget, trigger_event_name, subscribed_action = widget_subscription
+
+                widget.add_event_subscription(
+                    trigger_event_name=trigger_event_name,
+                    subscribed_actions=[
+                        self.actions(subscribed_action),
+                    ]
+                )
+
     def actions(self, name):
         """Return an event object to pass to add_event_subscription"""
         return Widget.Action(self, name)
