@@ -71,12 +71,12 @@ class KMLMapInput(KMLMap):
 
         kml = Kml()
 
-        PlantStyle = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        PlantStyle = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         PlantsFolder = kml.newfolder(name="Potential Facilities")
         for p in [PlantsFolder.newpoint(name=plant.name, coords=[(plant.longitude, plant.latitude)]) for plant in data_set.query(Plant).all()]:
             p.style = PlantStyle
 
-        ShopStyle = Style(iconstyle=IconStyle(scale=0.4, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/red-circle-lv.png')))
+        ShopStyle = Style(iconstyle=IconStyle(scale=0.4, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/red-circle-lv.png')))
         ShopsFolder = kml.newfolder(name="Shops")
         for p in [ShopsFolder.newpoint(name=shop.name, coords=[(shop.longitude, shop.latitude)]) for shop in data_set.query(Shop).all()]:
             p.style = ShopStyle
@@ -97,7 +97,7 @@ class KMLMapOutput(KMLMap):
         flows = data_set.query(Flow).all()
         PlantsUsed = list(set([flow.plant for flow in flows]))
 
-        PlantStyle = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
+        PlantStyle = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         PlantsUsedFolder = kml.newfolder(name="Facilities Chosen")
         for p in [PlantsUsedFolder.newpoint(name=plant.name, coords=[(plant.longitude, plant.latitude)]) for plant in PlantsUsed]:
             p.style = PlantStyle
@@ -105,7 +105,7 @@ class KMLMapOutput(KMLMap):
         for p in [PlantsNotUsedFolder.newpoint(name=plant.name, coords=[(plant.longitude, plant.latitude)]) for plant in data_set.query(Plant).all() if plant not in PlantsUsed]:
             p.style = PlantStyle
 
-        ShopStyle = Style(iconstyle=IconStyle(scale=0.4, icon=Icon(href='http://maps.google.com/mapfiles/kml/paddle/red-circle-lv.png')))
+        ShopStyle = Style(iconstyle=IconStyle(scale=0.4, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/red-circle-lv.png')))
         for plant in PlantsUsed:
             CatchmentFolder = kml.newfolder(name="Catchment for " + plant.name)
             for point in [CatchmentFolder.newpoint(name=shop.name, coords=[(shop.longitude, shop.latitude)]) for shop in [flow.shop for flow in plant.flows]]:
@@ -193,14 +193,14 @@ class MyFacilityLocationSolverApp(AppWithDataSets):
         return [step_group1, step_group2, step_group3]
 
     def get_icon_url(self):
-        return 'http://www.tropofy.com/static/css/img/tropofy_example_app_icons/facility_location.png'
+        return 'http://tropofy.com/static/css/img/tropofy_example_app_icons/facility_location.png'
 
     def get_home_page_content(self):
         return {
             'content_app_name_header': '''
             <div>
             <span style="vertical-align: middle;">Facility Location Optimisation</span>
-            <img src="http://www.tropofy.com/static/css/img/tropofy_example_app_icons/facility_location.png" alt="main logo" style="width:15%">
+            <img src="http://tropofy.com/static/css/img/tropofy_example_app_icons/facility_location.png" alt="main logo" style="width:15%">
             </div>''',
 
             'content_single_column_app_description': '''
